netapp_ontap.models.security_association_ipsec API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.security_association_ipsec`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class SecurityAssociationIpsecSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the SecurityAssociationIpsec object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `action: str GET POST PATCH`

    Action for the IPsec security association.

    Valid choices:

    - bypass
    - discard
    - esp_transport
  `inbound: SecurityAssociationIpsecInbound GET POST PATCH`

    Status for inbound parameters for the IPsec security association.

  `outbound: SecurityAssociationIpsecOutbound GET POST PATCH`

    Status for outbound parameters for the IPsec security association.

  `state: str GET POST PATCH`

    State of the IPsec security association.